@@ -58,15 +58,15 @@ class BasePriceFloat(Text, ABC):
     def _max_value_config(self):
         return None
 
-    def _parse_value(
+    def parse_value(
         self,
         value: Any,
         data: Any,
     ):
 
-        value = super()._parse_value(value=value, data=data)
+        value = super().parse_value(value=value, data=data)
 
-        if not value:
+        if value is None:
             return None
 
         value = price.to_float(
@@ -74,10 +74,7 @@ class BasePriceFloat(Text, ABC):
             decimals=self._decimals,
         )
 
-        if value is None:
-            return None
-
-        return self._process_min_max_value(value)
+        return None if value is None else self._process_min_max_value(value)
 
     def _process_min_max_value(self, value: float) -> Optional[float]:
         min_value = self._min_value
@@ -107,24 +104,24 @@ class PriceFloat(BasePriceFloat):
 
 
 class PriceInt(PriceFloat):
-    def _parse_value(
+    def parse_value(
         self,
         value: Any,
         data: Any,
     ):
 
-        value = super()._parse_value(value=value, data=data)
+        value = super().parse_value(value=value, data=data)
 
-        return int(value) if value else None
+        return None if value is None else int(value)
 
 
 class PriceText(PriceFloat):
-    def _parse_value(
+    def parse_value(
         self,
         value: Any,
         data: Any,
     ):
 
-        value = super()._parse_value(value=value, data=data)
+        value = super().parse_value(value=value, data=data)
 
-        return str(value) if value else None
+        return None if value is None else str(value)
