@@ -1,9 +1,11 @@
+from types import GeneratorType
 from typing import Any, Callable, List, Optional, Union
 
-from easytxt.text import to_list
+from easytxt.text import to_list as multiply_to_list
 from pyquery import PyQuery
 
 from easydata.config.loader import ConfigLoader
+from easydata.data import DataBag
 from easydata.parsers.base import Base
 from easydata.processors.base import BaseProcessor
 
@@ -132,14 +134,93 @@ def iter_attr_data_from_obj(
         yield attr_name, attr_value
 
 
+def data_to_data_bag(
+    data: Optional[Union[Any, DataBag]] = None,
+    **kwargs,
+):
+
+    if not isinstance(data, DataBag):
+        if data:
+            kwargs["main"] = data
+
+        return DataBag(**kwargs)
+
+    if kwargs:
+        for data_name, data_value in kwargs.items():
+            data.add(data_name, data_value)
+
+    return data
+
+
+def apply_data_processor(processor, value):
+    if isinstance(value, GeneratorType):
+        for iter_value in value:
+            yield from processor.parse(iter_value)
+    else:
+        yield from processor.parse(value)
+
+
+def apply_data_processors(
+    value: Any,
+    processors: list,
+) -> Any:
+
+    for processor in processors:
+        value = apply_data_processor(processor, value)
+
+    yield from value
+
+
+def to_list(
+    value: Any,
+    split_key: Union[List[str], str],
+) -> list:
+
+    if not value:
+        return []
+
+    if isinstance(split_key, str):
+        split_key = [split_key]
+
+    value = str(value)
+
+    for single_split_key in split_key:
+        if single_split_key in value:
+            return [v.strip() for v in value.split(single_split_key)]
+
+    return [value]
+
+
 def multiply_list_values(
     list_values: list,
-    split_key: Optional[str] = None,
     multiply_keys: Optional[Union[list, tuple]] = None,
 ) -> list:
 
     new_all_list_values = []
 
+    for list_value in list_values:
+        if not list_value:
+            continue
+
+        new_list_values = multiply_to_list(
+            value=list_value,
+            multiply_keys=multiply_keys,
+        )
+
+        for new_list_value in new_list_values:
+            if new_list_value:
+                new_all_list_values.append(new_list_value)
+
+    return new_all_list_values
+
+
+def multiply_list_values_by_split_key(
+    list_values: list,
+    split_key: Union[List[str], str],
+) -> list:
+
+    new_all_list_values = []
+
     for list_value in list_values:
         if not list_value:
             continue
@@ -147,7 +228,6 @@ def multiply_list_values(
         new_list_values = to_list(
             value=list_value,
             split_key=split_key,
-            multiply_keys=multiply_keys,
         )
 
         for new_list_value in new_list_values:
