@@ -6,66 +6,87 @@ from easydata.queries import jp, pq
 from tests.factory import data_html
 
 
-def test_union():
-    test_html = """
-        <p class="brand">EasyData</p>
-    """
-
-    union_parser = parsers.Union(
-        parsers.Text(pq(".brand-wrong::text")),
-        parsers.Text(pq(".brand::text")),
-    )
-    assert union_parser.parse(test_html) == "EasyData"
-
-
-def test_union_first():
+@pytest.mark.parametrize(
+    "test_parsers, result",
+    [
+        (
+            (
+                parsers.Text(pq(".brand-wrong::text")),
+                parsers.Text(pq(".brand::text")),
+            ),
+            "EasyData",
+        ),
+        (
+            (
+                parsers.Text(pq(".brand::text")),
+                parsers.Text(pq("#name::text")),
+            ),
+            "EasyData",
+        ),
+        (
+            (
+                parsers.Text(pq(".brand-wrong::text")),
+                parsers.Text(pq(".brand-wrong-again::text")),
+            ),
+            None,
+        ),
+        (
+            (
+                parsers.Bool(pq(".brand::text"), contains=["WrongData"]),
+                parsers.Bool(pq(".brand::text"), contains=["EasyData"]),
+            ),
+            True,
+        ),
+        (
+            (
+                parsers.List(pq(".brand-wrong::text-items")),
+                parsers.Text(pq(".brand::text")),
+            ),
+            "EasyData",
+        ),
+    ],
+)
+def test_or(test_parsers, result):
     test_html = """
         <p class="brand">EasyData</p>
         <p id="name">Easybook Pro 13</p>
     """
 
-    union_parser = parsers.Union(
-        parsers.Text(pq(".brand::text")),
-        parsers.Text(pq("#name::text")),
-    )
-    assert union_parser.parse(test_html) == "EasyData"
+    or_parser = parsers.Or(*test_parsers)
+    assert or_parser.parse(test_html) == result
 
 
-def test_union_none():
+@pytest.mark.parametrize(
+    "test_parsers, result",
+    [
+        (
+            (
+                parsers.List(pq(".brand-wrong::text-items")),
+                parsers.Text(pq(".brand::text")),
+            ),
+            [],
+        ),
+        (
+            (
+                parsers.Bool(pq(".brand::text"), contains=["WrongData"]),
+                parsers.Bool(
+                    pq(".brand::text"), default=False, contains=["Wrong2Data"]
+                ),
+            ),
+            False,
+        ),
+    ],
+)
+def test_or_strict_none_is_true(test_parsers, result):
     test_html = """
         <p class="brand">EasyData</p>
     """
 
-    union_parser = parsers.Union(
-        parsers.Text(pq(".brand-wrong::text")),
-        parsers.Text(pq(".brand-wrong-again::text")),
-    )
-    assert union_parser.parse(test_html) is None
-
-
-def test_union_strict_none_is_default_false():
-    test_html = """
-        <p class="brand">EasyData</p>
-    """
-
-    union_parser = parsers.Union(
-        parsers.List(pq(".brand-wrong::text-items")),
-        parsers.Text(pq(".brand::text")),
-    )
-    assert union_parser.parse(test_html) == "EasyData"
-
-
-def test_union_strict_none_is_true():
-    test_html = """
-        <p class="brand">EasyData</p>
-    """
-
-    union_parser = parsers.Union(
-        parsers.List(pq(".brand-wrong::text-items")),
-        parsers.Text(pq(".brand::text")),
+    or_parser = parsers.Or(
+        *test_parsers,
         strict_none=True,
     )
-    assert union_parser.parse(test_html) == []
+    assert or_parser.parse(test_html) == result
 
 
 def test_with():
@@ -168,6 +189,17 @@ def test_item_dict(ignore_non_values, result):
     assert item_dict_parser.parse(data_bag) == result
 
 
+def test_item_dict_exception_on_non_values():
+    item_dict_parser = parsers.ItemDict(
+        exception_on_non_values=True,
+        color=parsers.Text(jp("color")),
+        brand=parsers.Text(jp("features.brand")),
+    )
+
+    with pytest.raises(ValueError):
+        item_dict_parser.parse({"color": "gold"})
+
+
 @pytest.mark.parametrize(
     "ignore_non_values, result",
     [
